# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003-2004 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import os, os.path
import time

import Countries
import HRFData
import Terms
import SelectDateMenu
import EconomyDialog

from Common import *
from Commonwx import *
from wxPython.wx import *

class EconomyPage(wxPanel):
    ID_POPUP_MENU = 211
    ID_DATE_SELECTED = 212
    ID_EKONOM_BUTTON = 213

    Columns = [(_("This week"), "this"),
               (_("Last week"), "last"),
               (_("Difference"), "diff"),
               (_("Two weeks"), "two")]
    Rows = [(_("Revenue"), FACE_BOLD | FACE_BIG, "#C8F8C8", None, None),
            (_("Gate receipts"), FACE_NONE, "#F0F0F0", "Publik", "incomePublik"),
            (_("Sponsors"), FACE_NONE, "#E8E8E8", "Sponsorer", "IncomeSponsorer"),
            (_("Financial"), FACE_NONE, "#F0F0F0", "Finansiella", "incomeFinansiella"),
            (_("Temporary"), FACE_NONE, "#E8E8E8", "Tillfalliga", "incomeTillfalliga"),
            (_("Total"), FACE_BOLD, "#F0F0F0", "Summa", "incomeSumma"),
            None,
            (_("Expenses"), FACE_BOLD | FACE_BIG, "#F8C8C8", None, None),
            (_("Arena"), FACE_NONE, "#F0F0F0", "cArena", "costsArena"),
            (_("Player salaries"), FACE_NONE, "#E8E8E8", "cSpelare", "costsSpelare"),
            (_("Interests"), FACE_NONE, "#F0F0F0", "cRantor", "costsRantor"),
            (_("Temporary"), FACE_NONE, "#E8E8E8", "cTillfalliga", "costsTillfalliga"),
            (_("Staff"), FACE_NONE, "#F0F0F0", "cPersonal", "costsPersonal"),
            (_("Youth squad"), FACE_NONE, "#E8E8E8", "CJuniorverksamhet", "costsJuniorverksamhet"),
            (_("Total"), FACE_BOLD, "#F0F0F0", "cSumma", "costsSumma"),
            None,
            (_("Profit"), FACE_BOLD | FACE_BIG, "#C8C8F8", "Total", "total")]

    def __init__(self, parent, ID, filename):
        if filename == None:
            self.htdata = (None, None)
        else:
            self.htdata = (filename, HRFData.hrfstorage[filename])

        wxPanel.__init__(self, parent, ID)

        sizer = wxBoxSizer(wxVERTICAL)
        hsizer = wxBoxSizer(wxHORIZONTAL)

        self.htbutton = wxButton(self, EconomyPage.ID_POPUP_MENU, \
                                 _("Change date"), style = wxBU_EXACTFIT)
        hsizer.Add(self.htbutton, 0, wxALIGN_CENTRE | wxALL, 5)

        self.current_hrf_info = wxStaticText(self, -1, self.__get_current_text())
        hsizer.Add(self.current_hrf_info, 1, wxEXPAND | wxALL, 5)

        sizer.AddSizer(hsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        self.fgs = wxFlexGridSizer(cols=5, vgap=0, hgap=0)
        self.fgs.AddGrowableCol(1)
        self.fgs.AddGrowableCol(2)
        self.fgs.AddGrowableCol(3)
        self.fgs.AddGrowableCol(4)

        self.fgs.Add(wxStaticText(self, -1, ""))
        for col_name, col_attr in EconomyPage.Columns:
            stext = wxStaticText(self, -1, col_name, style = wxALIGN_RIGHT)
            SetTextBold(stext)
            self.fgs.Add(stext, 1, wxEXPAND | wxADJUST_MINSIZE | wxALL, 5)

        self.economy_texts = {}
        i = 0
        col_count = 0
        for row in EconomyPage.Rows:
            if row != None:
                row_name, row_face, row_colour, row_attr, row_data = row
            else:
                row_colour = None
            gpanel = SimpleColouredPanel(self, -1, row_colour)
            if row == None:
                stext = wxStaticText(gpanel, -1, "")
            else:
                stext = SetTextFace(wxStaticText(gpanel, -1, row_name,
                                                 style = wxALIGN_LEFT), row_face)
            gpanel.AddChild(stext, 1, wxEXPAND | wxADJUST_MINSIZE | wxALL, 5)
            self.fgs.Add(gpanel, 0, wxEXPAND | wxADJUST_MINSIZE | wxALL, 0)

            for col_name, col_attr in EconomyPage.Columns:
                gpanel = SimpleColouredPanel(self, -1, row_colour)
                stext = SetTextFace(wxStaticText(gpanel, -1, "",
                                                 style = wxALIGN_RIGHT | wxST_NO_AUTORESIZE),
                                    (row_face | FACE_BIG)^FACE_BIG)
                gpanel.AddChild(stext, 1, wxADJUST_MINSIZE | wxALIGN_RIGHT | wxALL, 5)
                self.fgs.Add(gpanel, 0, wxEXPAND | wxADJUST_MINSIZE | wxALL, 0)
                if row != None and row_attr != None and col_attr != None:
                    self.economy_texts[col_attr + row_attr] = stext
            self.fgs.AddGrowableRow(i)
            i += 1

        hsizer2 = wxBoxSizer(wxHORIZONTAL)
        hsizer2.AddSizer(self.fgs, 1, wxEXPAND |wxALL, 5)

        self.fgs2 = wxFlexGridSizer(cols=2, vgap=5, hgap=10)
        self.fgs2.AddGrowableCol(1)

        kapital=wxStaticText(self, -1, _("Capital"))
        SetTextBold(kapital)
        self.fgs2.Add(kapital)
        self.kapital=wxStaticText(self, -1, "")
        self.fgs2.Add(self.kapital, 1, wxADJUST_MINSIZE | wxALIGN_RIGHT | wxALIGN_BOTTOM | wxALIGN_TOP)
        resultat=wxStaticText(self, -1, _("Profit"))
        SetTextBold(resultat)
        self.fgs2.Add(resultat)
        self.resultat=wxStaticText(self, -1, "")
        self.fgs2.Add(self.resultat, 1, wxADJUST_MINSIZE | wxALIGN_RIGHT | wxALIGN_BOTTOM | wxALIGN_TOP)
        tillgang=wxStaticText(self, -1, _("Assets"))
        SetTextBold(tillgang)
        self.fgs2.Add(tillgang)
        self.tillgang=wxStaticText(self, -1, "")
        self.fgs2.Add(self.tillgang, 1, wxADJUST_MINSIZE | wxALIGN_RIGHT | wxALIGN_BOTTOM | wxALIGN_TOP)

        vsizer2 = wxBoxSizer(wxVERTICAL)
        vsizer2.AddSizer(self.fgs2, 1, wxEXPAND |wxALL, 20)

        self.economybutton = wxButton(self, EconomyPage.ID_EKONOM_BUTTON, \
                                      _("Economists"), style = wxBU_EXACTFIT)

        vsizer2.Add(self.economybutton, 0, wxEXPAND |wxALL | wxALIGN_CENTER, 20)
        hsizer2.AddSizer(vsizer2, 0, wxEXPAND |wxALL, 20)
        sizer.AddSizer(hsizer2, 0, wxEXPAND |wxALL, 5)

        self.SetSizer(sizer)
        self.SetAutoLayout(True)
        sizer.Fit(self)

        self.UpdateUI()

        EVT_BUTTON(self, EconomyPage.ID_POPUP_MENU, self.OnPopupMenu)
        EVT_BUTTON(self, EconomyPage.ID_EKONOM_BUTTON, self.EconomyButton)

    def ChangeHRF(self, hrffile):
        self.htdata = (hrffile, HRFData.hrfstorage[hrffile])
        self.current_hrf_info.SetLabel(self.__get_current_text())
        self.UpdateUI()

    def EconomyButton(self, event):
        tillgangar= self.htdata[1].get_section("economy").total+ \
                         self.htdata[1].get_section("economy").cash
        ekonom = self.htdata[1].get_section("club").ekonom
        dlg = EconomyDialog.EconomyDialog(self, tillgangar, ekonom,
                                          self.htdata[1].get_section("basics").leagueID)
        ret = dlg.ShowModal()

    def UpdateUI(self):
        if self.htdata == (None, None):
            return

        leagueid = self.htdata[1].get_section("basics").leagueID
        (dummy, dummy, currency,
         currency_is_prefix, exchangerate, dummy) = Countries.country_info[leagueid]
        for row in EconomyPage.Rows:
            if row == None:
                continue

            row_name, row_face, row_colour, row_attr, row_data = row
            if row_attr == None:
                continue

            lastrow_data = "last" + row_data[0].upper() + row_data[1:]

            for col_name, col_attr in EconomyPage.Columns:
                if col_name == None or col_attr == None:
                    continue
                value = None

                text = self.economy_texts[col_attr + row_attr]
                thisvalue = int(getattr(self.htdata[1].get_section("economy"), row_data)/exchangerate)
                lastvalue = int(getattr(self.htdata[1].get_section("economy"), lastrow_data)/exchangerate)
                diffvalue = thisvalue - lastvalue
                twovalue = thisvalue + lastvalue
                if col_attr == "this":
                    value = thisvalue
                elif col_attr == "last":
                    value = lastvalue
                elif col_attr == "diff":
                    value = diffvalue
                elif col_attr == "two":
                    value = twovalue
                if col_attr == "diff" or row_attr == "Total":
                    strvalue = add_currency_to_money(value, currency, currency_is_prefix, True)
                    if row_attr[0] == "c":
                        colval = -value
                    else:
                        colval = value
                    SetTextColour(text, colval)
                else:
                    strvalue = add_currency_to_money(value, currency, currency_is_prefix)
                text.SetLabel(strvalue)


        kapvalue=int(self.htdata[1].get_section("economy").cash/exchangerate)
        self.kapital.SetLabel(add_currency_to_money(kapvalue, currency, currency_is_prefix))
        self.resultat.SetLabel(add_currency_to_money(thisvalue, currency,
                                                     currency_is_prefix, True))
        SetTextColour(self.resultat,thisvalue)
        tillvalue=kapvalue+thisvalue
        self.tillgang.SetLabel(add_currency_to_money(tillvalue, currency, currency_is_prefix))

        self.Refresh()

    def OnPopupMenu(self, event):
        sdmenu = SelectDateMenu.SelectDateMenu(self, EconomyPage.ID_DATE_SELECTED,
                                               self.htdata[0])
        SelectDateMenu.EVT_DATE_SELECTED(sdmenu, EconomyPage.ID_DATE_SELECTED, \
                                         self.OnDateSelected)
        rect = self.htbutton.GetRect()
        self.PopupMenu(sdmenu, (rect[0], rect[1] + rect[3]))
        self.UpdateUI()

    def OnDateSelected(self, event):
        self.ChangeHRF(event.GetHRFFile())

    def __get_current_text(self):
        return htdata_text(self.htdata)
