# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003-2004 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import Images
import MatchInfo
import Terms

import string

from Common import *
from Commonwx import *
from wxPython.wx import *

class MatchDetailsDialog(wxDialog):
    ID_MP_HOME = 428
    ID_MP_AWAY = 429

    def __init__(self, parent, match_id):

        match = MatchInfo.MatchDetails(match_id)
        self.match = match

        if match.match_id is None:
            self.no_data = True
            return
        else:
            self.no_data = False

        hid = match.home_team[0]
        aid = match.away_team[0]

        title = "%s - %s" % (match.home_team[1], match.away_team[1])

        wxDialog.__init__(self, parent, -1, title, style = wxDEFAULT_DIALOG_STYLE)

        sizer=wxBoxSizer(wxVERTICAL)

        hsizer = wxBoxSizer(wxHORIZONTAL)

        dress_widget = self.__add_dress(match.home_team[2])
        hsizer.AddSizer(dress_widget, 0, wxALIGN_TOP | wxALL, 10)

        vsizer = wxBoxSizer(wxVERTICAL)

        matchtext = "%s - %s" % (match.home_team[1], match.away_team[1])
        if match.played:
            resulttext = "%d - %d" % (match.score[0], match.score[1])
        else:
            resulttext = "x - x"

        for t in [matchtext, resulttext]:
            stext = wxStaticText(self, -1, t)
            SetTextFace(stext, FACE_BOLD | FACE_BIG)
            vsizer.Add(stext, 0, wxALIGN_CENTRE | wxALL, 2)

        arenasizer = wxBoxSizer(wxHORIZONTAL)
        (id, name, weather, total, terraces, basic, roof, vip) = match.arena
        if weather is not None:
            weather_images = ["weather_rain.png", "weather_overcast.png",
                              "weather_cloudy.png", "weather_sun.png"]
            img = Images.Images.get_bitmap_from_file(weather_images[weather])
            sbmp = wxStaticBitmap(self, -1, img)
            arenasizer.Add(sbmp, 0, wxALIGN_CENTRE | wxALL, 10)

        atexts = [_("Arena") + ": " +  name]
        if total is not None:
            atexts.append(_("Attendance") + ": %d" % total)

        btexts = []
        for desc, amount in [(_("Terraces"), terraces),
                             (_("Basic seating"), basic),
                             (_("Roofed seating"), roof),
                             (_("Seating in VIP boxes"), vip)]:
            if amount is not None:
                btexts.append(desc + ": %d" % amount)

        i = 0
        for texts in [atexts, btexts]:
            if len(texts) > 0:
                avsizer = wxBoxSizer(wxVERTICAL)
                for t in texts:
                    stext = wxStaticText(self, -1, t)
                    if i == 0:
                        SetTextFace(stext, FACE_BOLD | FACE_BIG)
                    avsizer.Add(stext, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 2)
                    i += 1
                arenasizer.AddSizer(avsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        avsizer = wxBoxSizer(wxVERTICAL)
        arenasizer.AddSizer(avsizer, 0, wxALIGN_LEFT | wxALL, 5)

        vsizer.AddSizer(arenasizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        # Match events

        hteam_scores = {}
        ateam_scores = {}

        hid_orders = []
        aid_orders = []
        for minute, hgoals, agoals, team, id, name in match.scorers:
            if team == hid:
                scores = hteam_scores
                id_orders = hid_orders
            elif team == aid:
                scores = ateam_scores
                id_orders = aid_orders
            else:
                print match.scorers
                continue

            if not scores.has_key(id):
                scores[id] = (name, [])
                id_orders.append(id)
            scores[id][1].append(minute)

        hteam_bookings = []
        ateam_bookings = []

        for minute, type, team, id, name in match.bookings:
            if team == hid:
                hteam_bookings.append((minute, type, id, name))
            elif team == aid:
                ateam_bookings.append((minute, type, id, name))

        stext = wxStaticText(self, -1, _("Match events") + ":")
        SetTextFace(stext, FACE_BOLD | FACE_BIG)
        vsizer.Add(stext, 0, wxALIGN_LEFT | wxALL, 5)

        eventsizer = wxBoxSizer(wxHORIZONTAL)

        i = 0
        for scores, id_orders, bookings in [(hteam_scores, hid_orders, hteam_bookings),
                                            (ateam_scores, aid_orders, ateam_bookings)]:
            if i == 0:
                side = wxRIGHT
            else:
                side = wxLEFT
            evsizer = wxBoxSizer(wxVERTICAL)

            if len(scores.values()) > 0:
                fgsizer = wxFlexGridSizer(cols=2, vgap=0, hgap=0)
                for pid in id_orders:
                    (name, minutes) = scores[pid]
                    stext = wxStaticText(self, -1, name)
                    fgsizer.Add(stext, 0, wxALIGN_LEFT | wxRIGHT, 7)

                    min_text = string.join([str(m) for m in minutes], ", ")
                    stext = wxStaticText(self, -1, min_text)
                    fgsizer.Add(stext, 0, wxALIGN_LEFT | wxLEFT, 7)

                evsizer.AddSizer(fgsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

            for minute, type, id, name in bookings:
                if type == 1:
                    stext = wxStaticText(self, -1, _("%s booked") % name)
                    stext.SetForegroundColour("#AAAA00")
                elif type == 2:
                    stext = wxStaticText(self, -1, _("%s sent off") % name)
                    stext.SetForegroundColour("#DD0000")
                evsizer.Add(stext, 0, wxEXPAND | wxALIGN_LEFT | wxALL, 0)

            eventsizer.AddSizer(evsizer, 1, wxALIGN_TOP | wxTOP | wxBOTTOM | side, 5)
            i += 1

        vsizer.AddSizer(eventsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        # Ratings

        stext = wxStaticText(self, -1, _("Match ratings") + ":")
        SetTextFace(stext, FACE_BOLD | FACE_BIG)
        vsizer.Add(stext, 0, wxALIGN_LEFT | wxALL, 5)

        ratingsizer = wxBoxSizer(wxHORIZONTAL)

        i = 0
        for ratings in [match.home_ratings, match.away_ratings]:
            if i == 0:
                side = wxRIGHT
            else:
                side = wxLEFT

            rfsizer = wxFlexGridSizer(cols=2, vgap=0, hgap=0)

            for rname, rdesc in Terms.team_parts:
                r = ratings[rname]
                if Terms.player_abilities.has_key(r):
                    rstr = Terms.player_abilities[r]
                else:
                    rstr = _("Unknown")

                j = 0
                for t in [rdesc + ":", rstr]:
                    rside = (j == 0) and wxRIGHT or wxLEFT
                    stext = wxStaticText(self, -1, t)
                    rfsizer.Add(stext, 0, rside, 5)
                    j += 1

            button = wxButton(self, self.ID_MP_HOME + i*2, _("Matchprediction:\nHome team"))
            rfsizer.Add(button, 0, wxALIGN_TOP | wxTOP | wxBOTTOM | wxRIGHT, 5)
            EVT_BUTTON(self, self.ID_MP_HOME + i*2, self.MPCopy)

            button = wxButton(self, self.ID_MP_AWAY + i*2, _("Matchprediction:\nAway team"))
            rfsizer.Add(button, 0, wxALIGN_TOP | wxTOP | wxBOTTOM | wxLEFT, 5)
            EVT_BUTTON(self, self.ID_MP_AWAY + i*2, self.MPCopy)

            ratingsizer.AddSizer(rfsizer, 1, wxALIGN_TOP | wxTOP | wxBOTTOM | side, 5)

            i += 1


        vsizer.AddSizer(ratingsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        # Last dress

        hsizer.AddSizer(vsizer, 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        dress_widget = self.__add_dress(match.away_team[2])
        hsizer.AddSizer(dress_widget, 0, wxALIGN_TOP | wxALL, 10)

        sizer.AddSizer(hsizer, 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 2)

        # Line

        line = wxStaticLine(self, -1, style = wxLI_HORIZONTAL)
        sizer.Add(line, 0, wxEXPAND | wxALIGN_CENTRE, 5)

        # Ok / Cancel buttons

        button = wxButton(self, wxID_OK, _("Ok"))
        button.SetDefault()

        sizer.Add(button, 0, wxALIGN_RIGHT | wxALL, 10)

        self.SetSizer(sizer)
        self.SetAutoLayout(True)
        sizer.Fit(self)

    def MPCopy(self, event):
        eid = event.GetId() - self.ID_MP_HOME

        if eid < 2:
            ratings = self.match.home_ratings
        else:
            ratings = self.match.away_ratings

        import Main
        Main.notebook_pages["prediction"].ChangeRatings(ratings, (eid in [0, 2]))

    def __add_dress(self, cols):
        sizer = wxBoxSizer(wxVERTICAL)

        def_cols = ('N', 2, 4, 4)

        if cols is not None:
            dc = cols
        else:
            dc = def_cols

        nc = []
        for i in range(1, 4):
            if Terms.dress_colours.has_key(dc[i]):
                nc.append(Terms.dress_colours[dc[i]])
            else:
                nc.append(Terms.dress_colours[def_cols[i]])
        dress_cols = (dc[0], nc[0], nc[1], nc[2])

        dress_imgs = Images.create_dress_images(*dress_cols)
        for img in dress_imgs:
            sbmp = wxStaticBitmap(self, -1, img)
            sizer.Add(sbmp, 1, wxALIGN_LEFT | wxALL, 0)

        return sizer

class MatchLineupDialog(wxDialog):
    def __init__(self, parent, match_id, team_id):

        match_lineup = MatchInfo.MatchLineup(match_id, team_id)

        if match_lineup.match_id is None:
            self.no_data = True
            return
        else:
            self.no_data = False

        title = _("Lineup for %s") % match_lineup.team_name

        wxDialog.__init__(self, parent, -1, title, style = wxDEFAULT_DIALOG_STYLE)

        sizer=wxBoxSizer(wxVERTICAL)

        f_line = "%s %d: %s - %s\n" % (_("Match"),
                                       match_lineup.match_id,
                                       match_lineup.home_team[1],
                                       match_lineup.away_team[1])

        stext = wxStaticText(self, -1, f_line)
        SetTextFace(stext, FACE_BOLD | FACE_BIG)
        sizer.Add(stext, 0, wxEXPAND | wxALIGN_LEFT | wxALL, 5)

        lines = []
        if match_lineup.match_type is not None:
            lines.append(Terms.match_type[match_lineup.match_type])
        if match_lineup.match_date is not None:
            lines.append("%s: %s\n" % (_("Match date"),
                                       mktimestring(match_lineup.match_date)))

        lines.append(_("Total rating") + ": %.1f*" % match_lineup.total_rating)

        for line in lines:
            stext = wxStaticText(self, -1, line)
            sizer.Add(stext, 0, wxEXPAND | wxALIGN_LEFT | wxALL, 2)

        sizer.Add(5, 15)

        fgsizer = wxFlexGridSizer(cols=4, vgap=0, hgap=0)

        for i in range(1, 22):
            (id, name, rating, position, behaviour) = match_lineup.lineup[i]
            if id is None:
                continue

            role = Terms.team_role[i]
            if behaviour is not None:
                role += ", " + Terms.individual_order[behaviour]
            role += ":"

            for line in [role, name]:
                stext = wxStaticText(self, -1, line)
                fgsizer.Add(stext, 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 3)

            if rating is None:
                fgsizer.Add(5, 5)
                fgsizer.Add(5, 5)
            else:
                img = Images.create_star_image(int(rating*2))
                sbmp = wxStaticBitmap(self, -1, img)
                fgsizer.Add(sbmp, 1, wxALIGN_LEFT | wxALL, 3)

                stext = wxStaticText(self, -1, "(" + str(rating) + "*)")
                fgsizer.Add(stext, 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 3)

        sizer.AddSizer(fgsizer, 0, wxEXPAND | wxALIGN_LEFT | wxALL, 0)

        # Line

        line = wxStaticLine(self, -1, style = wxLI_HORIZONTAL)
        sizer.Add(line, 0, wxEXPAND | wxALIGN_CENTRE, 5)

        # Ok / Cancel buttons

        button = wxButton(self, wxID_OK, _("Ok"))
        button.SetDefault()

        sizer.Add(button, 0, wxALIGN_RIGHT | wxALL, 10)

        self.SetSizer(sizer)
        self.SetAutoLayout(True)
        sizer.Fit(self)
