# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003-2004 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

"""Player dialog, showing a players data."""

from Common import *

import CommonData
import Players
import Countries
import Terms
import TransferHistory

from Commonwx import *
from wxPython.wx import *
from Images import Images, create_star_image

class PlayerDialog(wxDialog):
    """Dialog showing data about a particular player."""

    def __init__(self, parent, player):
        """Setup the dialog.

         - parent -- The parent widget.
         - player -- The player data."""

        wxDialog.__init__(self, parent, -1, player.name,
                          style = wxRESIZE_BORDER | wxCAPTION | wxSYSTEM_MENU)

        main_sizer = wxBoxSizer(wxVERTICAL)

        self.header_panel = HeaderPanel(self, -1, player.name)
        main_sizer.Add(self.header_panel, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        # Some space

        main_sizer.Add(0, 5)

        # Displaying attributes
        attr_order_tabs = [
            (_("Information"),
             [(_("General"), ["CountryID", "PlayerForm", "InjuryLevel",
                              "Cards", "Specialty", "BestPosition"]),
              (_("Economy"), ["MarketValue", "Salary"]),
              (_("Personality"), ["Age", "Experience", "Agreeability",
                                  "Aggressiveness", "Honesty",
                                  "Leadership"]),
              (_("Coach"), ["TrainerData.TrainerType",
                            "TrainerData.TrainerSkill"]),
              (_("Abilities"), ["StaminaSkill", "KeeperSkill",
                                "PlaymakerSkill", "PassingSkill",
                                "WingerSkill", "DefenderSkill",
                                "ScorerSkill", "SetPiecesSkill"]),
              (_("Number of goals"), ["CareerGoals", "CupGoals",
                                      "LeagueGoals", "FriendliesGoals",
                                      "CareerHattricks"]),
              (_("National teams"), ["Caps", "CapsU20"])]),

            (_("Evaluation"),
             [(_("Goalkeeper"), ["goalie"]),
              (_("Wingback"), ["wingback", "wingback_offensive",
                               "wingback_defensive",
                               "wingback_towards_the_middle"]),
              (_("Central defender"), ["centraldefender",
                                       "centraldefender_offensive",
                                       "centraldefender_towards_the_wing"]),
              (_("Winger"), ["winger", "winger_offensive",
                             "winger_defensive",
                             "winger_towards_the_middle"]),
              (_("Midfielder"), ["innermid", "innermid_offensive",
                                 "innermid_defensive",
                                 "innermid_towards_the_wing"]),
              (_("Forward"), ["forward", "forward_defensive"])]),
            ]

        notebook = wxNotebook(self, -1)
        nbsizer = wxNotebookSizer(notebook)

        for descr, attr_order in attr_order_tabs:
            notebook.AddPage(AttributePanel(notebook, -1, player, attr_order), descr)

        notebook.AddPage(TransferHistoryPanel(notebook, -1, player), _("Transfers"))

        main_sizer.AddSizer(nbsizer, 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

        # Line

        line = wxStaticLine(self, -1, style = wxLI_HORIZONTAL)
        main_sizer.Add(line, 0, wxEXPAND | wxALIGN_CENTRE, 5)

        # Ok / Cancel buttons

        button = wxButton(self, wxID_OK, _("Ok"))
        button.SetDefault()

        main_sizer.Add(button, 0, wxALIGN_RIGHT | wxALL, 10)

        self.SetSizer(main_sizer)
        self.SetAutoLayout(True)
        main_sizer.Fit(self)

class AttributePanel(wxPanel):

    def __init__(self, parent, ID, player, attr_order):
        wxPanel.__init__(self, parent, ID)

        ssizer = wxBoxSizer(wxVERTICAL)

        row = 0
        row_col_alts = [0xF0F0F0, 0xF0F0F0, 0xE8E8E8, 0xE8E8E8]
        fg_sizer = wxFlexGridSizer(cols = 4, vgap = 0, hgap = 0)
        for i in range(4):
            fg_sizer.AddGrowableCol(i)

        for descr, attrs in attr_order:
            attrs = filter((lambda x: self.__check_optional_attribute(x, player)), attrs)
            if len(attrs) % 2 == 1:
                attrs = attrs + [None]

            if len(attrs) > 0:
                stext = wxStaticText(self, -1, descr)
                SetTextFace(stext, FACE_BOLD)
                fg_sizer.Add(stext, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 2)

                for i in range(3):
                    fg_sizer.Add(0, 0)

                for attr in attrs:
                    if bool(row % 2):
                        right_s = 0
                        left_s = 4
                    else:
                        right_s = 4
                        left_s = 0
                    spanel = SimpleColouredPanel(self, -1,
                                                 "#%06X" % (row_col_alts[row % 4] & 0xCCCCCC))
                    if attr is not None:
                        stext = wxStaticText(spanel, -1, Players.player_attr_conf[attr][0],
                                             style = wxALIGN_LEFT)
                        spanel.AddChild(stext, 1,
                                        wxEXPAND | wxADJUST_MINSIZE | wxALIGN_LEFT | wxALL, 2)
                    fg_sizer.Add(spanel, 0,
                                 wxEXPAND | wxALIGN_CENTRE | wxADJUST_MINSIZE | wxLEFT, left_s)

                    spanel = SimpleColouredPanel(self, -1,
                                                 "#%06X" % (row_col_alts[row % 4] & 0xFFFFFF))
                    if attr is not None:
                        self.__add_attribute_widgets(attr, player, spanel)
                    fg_sizer.Add(spanel, 0,
                                 wxEXPAND | wxALIGN_CENTRE | wxADJUST_MINSIZE | wxRIGHT, right_s)
                    row += 1

        ssizer.Add(fg_sizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        self.SetSizer(ssizer)
        self.SetAutoLayout(True)
        ssizer.Fit(self)

    def __check_optional_attribute(self, attr, player):
        if attr == "InjuryLevel" and player.get(attr, -1) < 0:
            return False

        if attr == "Cards" and player.get(attr, 0) == 0:
            return False

        if attr == "Specialty" and player.get(attr, 0) == 0:
            return False

        if attr.startswith("TrainerData") and player.get(attr) == None:
            return False

        if attr in ["Caps", "CapsU20"] and player.get(attr, 0) == 0:
            return False

        return True

    def __add_attribute_widgets(self, attr, player, spanel):
        if attr == "InjuryLevel":
            injury_level = player.get(attr, -1)
            if injury_level > 0:
                img = Images.get_bitmap_from_file("injury.png")
                sbmp = wxStaticBitmap(spanel, -1, img, style = wxALIGN_LEFT)
                spanel.AddChild(sbmp, 0, wxEXPAND | wxADJUST_MINSIZE | wxALIGN_LEFT | wxALL, 2)

        elif attr == "Cards":
            img_files = {1: "yellowcard.png", 2: "2yellowcards.png", 3: "redcard.png"}

            img_file = img_files.get(player.get(attr, 0))
            if img_file is not None:
                img = Images.get_bitmap_from_file(img_file)
                sbmp = wxStaticBitmap(spanel, -1, img, style = wxALIGN_LEFT)
                spanel.AddChild(sbmp, 0, wxEXPAND | wxADJUST_MINSIZE | wxALIGN_LEFT | wxALL, 2)
            return

        elif attr == "CountryID":
            cid = Countries.country.get(player.get(attr))
            cinfo = Countries.country_info.get(cid)
            if cinfo is not None:
                img = Images.get_bitmap_from_file(cinfo[5])
                sbmp = wxStaticBitmap(spanel, -1, img, style = wxALIGN_LEFT)
                spanel.AddChild(sbmp, 0, wxEXPAND | wxADJUST_MINSIZE | wxALIGN_LEFT | wxALL, 2)

        stext = wxStaticText(spanel, -1, player.get(attr, "", True),
                             style = wxALIGN_LEFT)
        spanel.AddChild(stext, 1, wxEXPAND | wxADJUST_MINSIZE | wxALIGN_LEFT | wxALL, 2)

class TransferHistoryPanel(wxPanel):
    def __init__(self, parent, ID, player):
        wxPanel.__init__(self, parent, ID)

        self.__player = player
        self.__transfer_history = TransferHistory.TransferHistory(self.__player.id, "player")

        row_col_alts = [0xF0F0F0, 0xE8E8E8]
        fg_sizer = wxFlexGridSizer(cols = 2, vgap = 0, hgap = 0)
        for i in range(2):
            fg_sizer.AddGrowableCol(i)

        for t in self.__transfer_history.transfers:
            col = 0

            stext = wxStaticText(self, -1, t.get("Deadline", 0.0, display = True))
            SetTextBold(stext)
            fg_sizer.Add(stext, 0, wxEXPAND | wxALIGN_LEFT | wxALL, 2)
            fg_sizer.Add(0,0)

            info = [("in_arrow.png",
                     t.get("Buyer.BuyerTeamName", _("Unknown"), display = True),
                     t.get("Price", CommonData.add_currency(0), display = True)),
                    ("out_arrow.png",
                     t.get("Seller.SellerTeamName", _("Unknown"), display = True),
                     "(%s)" % t.get("MarketValue", CommonData.add_currency(0), display = True))]

            row = 0

            for arrow_file, teamname, price in info:
                colour = "#%06X" % (row_col_alts[row % 2] & 0xFFFFFF)

                # Buyer/Seller
                spanel = SimpleColouredPanel(self, -1, colour, wxHORIZONTAL)

                img = Images.get_bitmap_from_file(arrow_file)
                sbmp = wxStaticBitmap(spanel, -1, img, style = wxALIGN_LEFT)
                spanel.AddChild(sbmp, 0, wxEXPAND | wxALIGN_LEFT | wxALL, 2)

                stext = wxStaticText(spanel, -1, teamname, style = wxALIGN_LEFT)
                spanel.AddChild(stext, 0, wxALIGN_LEFT | wxALL, 2)
                fg_sizer.Add(spanel, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

                # Price/Marketvalue
                spanel = SimpleColouredPanel(self, -1, colour, wxVERTICAL)
                stext = wxStaticText(spanel, -1, price, style = wxALIGN_RIGHT)
                spanel.AddChild(stext, 0, wxALIGN_RIGHT | wxALL, 2)
                fg_sizer.Add(spanel, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

                row += 1

        self.SetSizer(fg_sizer)
        self.SetAutoLayout(True)
        fg_sizer.Fit(self)
