# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003-2004 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

"""Functions and classes to help pulling out relevant information of
the players xml."""

from Common import *
import XMLParse
import CommonData
from Database import databases
import TeamEvaluation
import Terms
import TeamInfo
import Countries

from sets import Set
import time

known_player_attrs = Set([
    "PlayerID", "PlayerName", "PlayerNumber", "Age", "MarketValue",
    "PlayerForm", "Statement", "Experience", "Leadership", "Salary",
    "Agreeability", "Aggressiveness", "Honesty", "LeagueGoals", "CupGoals",
    "FriendliesGoals", "CareerGoals", "CareerHattricks", "Specialty",
    "TransferListed", "Cards", "InjuryLevel", "StaminaSkill",
    "KeeperSkill", "PlaymakerSkill", "ScorerSkill", "PassingSkill",
    "WingerSkill", "DefenderSkill", "SetPiecesSkill",
    "TrainerData.TrainerType", "TrainerData.TrainerSkill", "CountryID",
    "Caps", "CapsU20",
    ])

mALIGN_LEFT = 0
mALIGN_CENTRE = 1
mALIGN_RIGHT = 2

player_attr_conf = {
    "PlayerID": (_("ID"), mALIGN_CENTRE, False),
    "PlayerName": (_("Name"), mALIGN_LEFT, True),
    "PlayerNumber": (_("Shirt number"), mALIGN_RIGHT, True),
    "Age": (_("Age"), mALIGN_RIGHT, True),
    "MarketValue": (_("Market value"), mALIGN_RIGHT, False),
    "PlayerForm": (_("Form"), mALIGN_LEFT, False),
    "Statement": (_("Statement"), mALIGN_LEFT, True),
    "Experience": (_("Experience"), mALIGN_LEFT, False),
    "Leadership": (_("Leadership"), mALIGN_LEFT, False),
    "Salary": (_("Salary"), mALIGN_RIGHT, False),
    "Agreeability": (_("Agreeability"), mALIGN_LEFT, False),
    "Aggressiveness": (_("Aggressiveness"), mALIGN_LEFT, False),
    "Honesty": (_("Honesty"), mALIGN_LEFT, False),
    "LeagueGoals": (_("League goals"), mALIGN_RIGHT, False),
    "CupGoals": (_("Cup goals"), mALIGN_RIGHT, False),
    "FriendliesGoals": (_("Goals in friendlies"), mALIGN_RIGHT, False),
    "CareerGoals": (_("Career goals"), mALIGN_RIGHT, False),
    "CareerHattricks": (_("Career Hattricks"), mALIGN_RIGHT, False),
    "CompetitionGoals": (_("Competition goals"), mALIGN_RIGHT, False),
    "SeasonGoals": (_("Goals in this season"), mALIGN_RIGHT, False),
    "Specialty": (_("Speciality"), mALIGN_LEFT, True),
    "TransferListed": (_("Transfer listed?"), mALIGN_LEFT, True),
    "Cards": (_("Bookings"), mALIGN_CENTRE, False),
    "InjuryLevel": (_("Injury time"), mALIGN_RIGHT, False),
    "StaminaSkill": (_("Stamina"), mALIGN_LEFT, False),
    "KeeperSkill": (_("Goalkeeper"), mALIGN_LEFT, False),
    "PlaymakerSkill": (_("Playmaking"), mALIGN_LEFT, False),
    "ScorerSkill": (_("Scoring"), mALIGN_LEFT, False),
    "PassingSkill": (_("Passing"), mALIGN_LEFT, False),
    "WingerSkill": (_("Winger"), mALIGN_LEFT, False),
    "DefenderSkill": (_("Defending"), mALIGN_LEFT, False),
    "SetPiecesSkill": (_("Set pieces"), mALIGN_LEFT, False),
    "TrainerData.TrainerType": (_("Coach type"), mALIGN_LEFT, False),
    "TrainerData.TrainerSkill": (_("Coaching ability"), mALIGN_LEFT, False),
    "CountryID": (_("Country"), mALIGN_RIGHT, True),
    "Caps": (_("National caps"), mALIGN_RIGHT, False),
    "CapsU20": (_("National U-20 caps"), mALIGN_RIGHT, False),
    "BestPosition": (_("Best position"), mALIGN_LEFT, True),
    }

def add_team_positions_to_player_attr_conf():
    global player_attr_conf
    for i, (position, descr) in Terms.team_positions.items():
        player_attr_conf[position] = (descr, mALIGN_RIGHT, False)

add_team_positions_to_player_attr_conf()

class Player(CommonData.DataStore):
    """Class that contains information about a player."""

    def __init__(self, data):
        """Takes player data and initializes the class."""

        CommonData.DataStore.__init__(self, data)

        self.id = self.get("PlayerID", None, False)
        self.name = self.get("PlayerName", "", True)

class Players:
    """Class that extracts and stores information about all players
    from a particular date."""


    def __init__(self,  date = None):
        """Initialize the structure.

         - date -- A quadruple of (year, month, day, hour) telling which
                   day and hour to fetch players for."""

        team = CommonData.get_current_teamid()
        if date == None:
            userid = int(databases.get(None, False, "Mattricks.current_userid")),
            xlist = databases.get(userid, False, "all players.xml_list")
            if xlist is None or len(xlist) == 0:
                date = time.localtime(time.time())[0:4]
            else:
                dstr = xlist.split()[-1][-13:]
                try:
                    date = (int(dstr[0:4]),
                            int(dstr[5:7]),
                            int(dstr[8:10]),
                            int(dstr[11:13]))
                except (ValueError, KeyError), err:
                    date = time.localhost(time.time())[0:4]

        self.__extract_data(date, team)

    def __extract_data(self, date, team):
        """Extracts the data and put it into player structures.

         - date -- A quadruple of (year, month, day, hour) telling which
                   day and hour to fetch players for.
         - team -- Which teams players to fetch for."""

        ndata = XMLParse.get(["all players", team, date],
                             normal = True, display = False)
        ddata = XMLParse.get(["all players", team, date],
                             normal = False, display = True)

        self.team_id = ndata.get("Team.TeamID")
        self.team_name = ddata.get("Team.TeamName", "")
        team=TeamInfo.TeamInfo(self.team_id)
        self.league_id=team.league_id
        
        player_indices = CommonData.get_xml_list_indices("Team.PlayerList.Player", ndata)
        self.all_players = {}
        for pindex in player_indices:
            if ndata.get("Team.PlayerList.Player%s.PlayerID" % pindex) is None:
                break
            pdata = {}
            for pattr in known_player_attrs:
                pdata[pattr] = (ndata.get("Team.PlayerList.Player%s.%s" % (pindex, pattr)),
                                ddata.get("Team.PlayerList.Player%s.%s" % (pindex, pattr)))

            player = Player(pdata)

            surname = name2surname(player.get("PlayerName", "?"))
            player.data["PlayerSurname"] = (surname, surname)

            if not (self.league_id == Countries.country[player.get("CountryID")]):
                new_salary=int(1.2*player.get("Salary"))
                player.data["Salary"] = (new_salary, CommonData.add_currency(new_salary))
                
            compgoals = player.get("CupGoals", 0) + player.get("LeagueGoals", 0)
            player.data["CompetitionGoals"] = (compgoals,
                                               ngettext("%d goal", "%d goals", compgoals) % compgoals)

            seasgoals = player.get("CompetitionGoals", 0) + player.get("FriendliesGoals", 0)
            player.data["SeasonGoals"] = (seasgoals,
                                          ngettext("%d goal", "%d goals", seasgoals) % seasgoals)

            self.all_players[player.id] = player

        player_eval_table = TeamEvaluation.TeamEvaluation.calculate_player_table(self.all_players)

        bpos = {}
        for pid in self.all_players.keys():
            bpos[pid] = (None, None, None)

        for i, (position, descr) in Terms.team_positions.items():
            count = 0
            for pval, pid in player_eval_table[i]:
                count += 1

                self.all_players[pid].data[position] = ((pval, count),
                                                        "%.2f (%d)" % (pval, count))

                if pval > bpos[pid][2]:
                    bpos[pid] = (i, descr, pval)

        for pid, (i, descr, pval) in bpos.items():
            if i is not None:
                self.all_players[pid].data["BestPosition"] = ((i, pval),
                                                              "%s (%.2f)" % (descr, pval))

class PlayerHistory:
    """Class that traces one or more attributes of a player through
    a period of time."""

